This is package that contains all modules needed to run
the database and other configurations
Contents:
    1. Lykkelle system email sender
    2. parameters are as follows:
    sendername="name of sender"
    sender_email="sender email"
    receivername="Deb Mishra"
    receivers=[{"email":"<email id>","name":"sender name"}]
    subject="Email subject. Not needed if template id 2 is there"
    message="Message body for plain test message"
    template = possible values- jobname,jobdetails,firstname,password
    templateid= possible values - 2,3
